@@ -16,12 +16,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
- 
+
 #ifndef HAVE_SCREENSHOOTER_H
 #define HAVE_SCREENSHOOTER_H
 
 #include "screenshooter-dialogs.h"
 #include "screenshooter-utils.h"
 #include "screenshooter-actions.h"
+#include "screenshooter-capture.h"
+#include "screenshooter-global.h"
 
 #endif
