@@ -21,8 +21,16 @@
 #define __HAVE_ACTIONS_H__
 
 #include "screenshooter-utils.h"
+#include "screenshooter-capture.h"
+#include "screenshooter-global.h"
 #include "screenshooter-dialogs.h"
 
-void screenshooter_take_and_output_screenshot (ScreenshotData *sd);
+#ifdef HAVE_XMLRPC
+#ifdef HAVE_CURL
+#include "screenshooter-zimagez.h"
+#endif
+#endif
+
+gboolean screenshooter_take_and_output_screenshot (ScreenshotData *sd);
 
 #endif
