@@ -19,11 +19,14 @@
 
 #ifndef __HAVE_DIALOGS_H__
 #define __HAVE_DIALOGS_H__
- 
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#include "screenshooter-utils.h"
+#include "screenshooter-global.h"
+
 #ifdef HAVE_GIO
 #include <gio/gio.h>
 #endif
@@ -32,15 +35,11 @@
 #include <libxfce4util/libxfce4util.h>
 #include <libxfcegui4/libxfcegui4.h>
 
-#include "screenshooter-utils.h"
 
 
-
-GtkWidget   
-*screenshooter_dialog_new          (ScreenshotData      *sd, 
-                                    gboolean             plugin);
-gchar 
-*screenshooter_save_screenshot     (GdkPixbuf           *screenshot, 
-                                    gboolean             show_save_dialog,
-                                    gchar               *default_dir);
-#endif                                    
+GtkWidget *screenshooter_dialog_new  (ScreenshotData *sd,
+                                      gboolean        plugin);
+gchar *screenshooter_save_screenshot (GdkPixbuf      *screenshot,
+                                      gboolean        show_save_dialog,
+                                      const gchar    *default_dir);
+#endif
